==> MuSE-0.7.2.tar.gz: MuSE-0.7.2/ncursesgui/connectbox.cpp <==
/* A NCURSES/CDK TUI (Text User Interface) for MuSE
 * Copyright (C) 2002 Luca 'rubik' Profico <rubik@olografix.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: connectbox.cpp,v 1.12 2002/07/04 17:37:55 rubik Exp $
 *
 */

#include "connectbox.h"
#include "muse_console.h"

ConnectBox::ConnectBox (Stream_mixer *m)
{

	mixer = m ;

	func ("ConnectBox::ConnectBox");
	
	ybase = (LINES-CONNBOX_HEIGHT)/2;
	xbase = (COLS-CONNBOX_WIDTH)/2;
	subwin = newwin (CONNBOX_HEIGHT, CONNBOX_WIDTH, ybase, xbase);

	cdkscreen = initCDKScreen (subwin);
	box (subwin, ACS_VLINE, ACS_HLINE);
	wrefresh (subwin);

	/* icecast settings */
	host.setscreen (cdkscreen); host.box=FALSE;
	port.setscreen (cdkscreen); port.box=FALSE;
	mnt.setscreen (cdkscreen); mnt.box=FALSE;
	name.setscreen (cdkscreen); name.box=FALSE;
	url.setscreen (cdkscreen); url.box=FALSE;
	description.setscreen (cdkscreen); description.box=FALSE;
	logintype.setscreen (cdkscreen); logintype.box=FALSE;
	pass.setscreen (cdkscreen); pass.box=FALSE;

	/* lame settings */
	bitrate.setscreen (cdkscreen); bitrate.box=FALSE;
	filtering.setscreen (cdkscreen); filtering.box=FALSE;
	frequency.setscreen (cdkscreen); frequency.box=FALSE;
	lowpasshz.setscreen (cdkscreen); lowpasshz.box=FALSE;
	channels.setscreen (cdkscreen); channels.box=FALSE;
	highpasshz.setscreen (cdkscreen); highpasshz.box=FALSE;
	quality.setscreen (cdkscreen); quality.box=FALSE;


	/* entry list definitions */

	logtypelist[0] = strdup ("x-audiocast");
	logtypelist[1] = strdup ("icy");

	bitratelist[0] = strdup ("8");
	bitratelist[1] = strdup ("16");
	bitratelist[2] = strdup ("24");
	bitratelist[3] = strdup ("32");
	bitratelist[4] = strdup ("56");
	bitratelist[5] = strdup ("64");
	bitratelist[6] = strdup ("96");
	bitratelist[7] = strdup ("128");

	freqlist[0] = strdup ("auto");
	freqlist[1] = strdup ("11000");
	freqlist[2] = strdup ("16000");
	freqlist[3] = strdup ("22050");
	freqlist[4] = strdup ("44100");

	chanlist[0] = strdup ("0 - stereo");
	chanlist[1] = strdup ("1 - jstereo");
	chanlist[2] = strdup ("2 - dual chan");
	chanlist[3] = strdup ("3 - mono");

	qualitylist[0] = strdup ("1 (best)");
	qualitylist[1] = strdup ("2");
	qualitylist[2] = strdup ("3");
	qualitylist[3] = strdup ("4");
	qualitylist[4] = strdup ("5");
	qualitylist[5] = strdup ("6");
	qualitylist[6] = strdup ("7");
	qualitylist[7] = strdup ("8");
	qualitylist[8] = strdup ("9 (worst)");
	
	filteringlist[0] = strdup ("auto");
	filteringlist[1] = strdup ("none");
	filteringlist[2] = strdup ("manual");

	/* menu entries */
	icecastml[0] = strdup (" ");
	icecastml[1] = strdup ("<C>Icecast");
	icecastml[2] = strdup ("<C>-");
	icecastml[3] = strdup ("<C></48>b<!48></32>rowse profiles<!32>");
	icecastml[4] = strdup ("<C></48>s<!48></32>ave profile<!32>");
	icecastml[5] = strdup ("<C></48>c<!48></32>onnect<!32>");
	icecastml[6] = strdup ("<C></32>e<!32></48>x<!48></32>it<!32>");
	icecastml[7] = strdup (" ");

	lameml[0] = strdup (" ");
	lameml[1] = strdup ("<C>Lame");
	lameml[2] = strdup ("<C>-");
	lameml[3] = strdup ("<C></48>b<!48></32>rowse profiles<!32>");
	lameml[4] = strdup ("<C></48>s<!48></32>ave profile<!32>");
	lameml[5] = strdup ("<C></48>a<!48></32>pply<!32>");
	lameml[6] = strdup ("<C></32>e<!32></48>x<!48></32>it<!32>");
	lameml[7] = strdup (" ");

	/* labels */
	bottom.setscreen (cdkscreen);
	label1.setscreen (cdkscreen);
	label2.setscreen (cdkscreen);
	icecastmenu.setscreen (cdkscreen);
	lamemenu.setscreen (cdkscreen);

	/* load default profiles */
	mixer->lame.load_profile("last_active");
	mixer->ice.load_profile("last_active");
}

void ConnectBox::setparm (void)
{


	/* icecast settings */
	host.setparm (NULL, "</48>h<!48></32>ost:<!32>", 20, xbase + 2, ybase + 3, false, '_');
	port.setparm (NULL, "</32>p<!32></48>o<!48></32>rt:<!32>", 5, xbase + 32, ybase + 3, false, '_');
	mnt.setparm (NULL, "</48>m<!48></32>nt:<!32>", 15, xbase + 45, ybase + 3, false, '_');
	
	name.setparm (NULL, "</48>n<!48></32>ame:<!32>", 27, xbase + 2, ybase + 5, false, '_');
	url.setparm (NULL, "</48>u<!48></32>rl:<!32>", 22, xbase + 38, ybase + 5, false, '_');
	
	description.setparm (NULL, "</48>d<!48></32>escription:<!32>", 50, xbase + 2, ybase + 7, false, '_');
	
	logintype.setparm (NULL, "</32>logint<!32></48>y<!48></32>pe:<!32>", xbase + 1, ybase + 9, logtypelist, 2, 0, false);
	pass.setparm (NULL, "</48>p<!48></32>ass:<!32>", 18, xbase + 29, ybase + 9, false, '_', A_REVERSE, vHMIXED);

	/* lame settings */
	bitrate.setparm (NULL, "</48>b<!48></32>itrate:<!32>", xbase +1, ybase +13, bitratelist, 8, 2, false);
	filtering.setparm  (NULL, "</32>freq. fil<!32></48>t<!48></32>ering:<!32>", xbase +15, ybase +13, filteringlist, 3, 0, false);
	frequency.setparm (NULL, "</48>f<!48></32>requency:<!32>", xbase+44, ybase +13, freqlist, 5, 2, false);
	lowpasshz.setparm (NULL, "</48>l<!48></32>owpassHZ:<!32>", 5, xbase +2, ybase+15, false, '_');
	highpasshz.setparm (NULL, "</32>h<!32></48>i<!48></32>ghpassHZ:<!32>", 5, xbase +20, ybase+15, false, '_');
	channels.setparm (NULL, "</48>c<!48></32>hannels:<!32>", xbase +37, ybase +15, chanlist, 4, 0, false);
	quality.setparm (NULL, "</48>q<!48></32>uality:<!32>", xbase+1, ybase +17, qualitylist, 9, 3, false);


	label1.setparm (xbase, ybase,20, 1);
	label1.setvalue ("IceCast settings:");
	label2.setparm (xbase, ybase + 11 ,20, 1);
	label2.setvalue ("Lame settings:");

	icecastmenu.box=TRUE;
	icecastmenu.setparm (xbase + CONNBOX_WIDTH/2 - 10, ybase + CONNBOX_HEIGHT/2 - 5 , 20, 8);
	icecastmenu.setvalueNR (icecastml, 8);
	icecastmenu.unreg();

	lamemenu.box=TRUE;
	lamemenu.setparm (xbase + CONNBOX_WIDTH/2 - 10, ybase + CONNBOX_HEIGHT/2 - 5 , 20, 8);
	lamemenu.setvalueNR (lameml, 8);
	lamemenu.unreg();

	bottom.box=TRUE;
	bottom.setparm (xbase +3 , ybase + CONNBOX_HEIGHT,CONNBOX_WIDTH -6 ,1);
	bottom.llhook (ACS_BTEE);
	bottom.lrhook (ACS_BTEE);
	bottom.setvalue ("<C>Connbox");

	showcurrval();
}

void ConnectBox::draw (void)
{
	/*
	host.draw();
	port.draw();
	mnt.draw();
	name.draw();
	url.draw();
	description.draw();
	logintype.draw();
	pass.draw();
	bitrate.draw();
	filtering.draw();
	frequency.draw();
	lowpasshz.draw();
	highpasshz.draw();
	channels.draw();
	quality.draw();
	bottom.draw();
	*/

	refresh();
}

void ConnectBox::refresh (void)
{
	refreshCDKScreen (cdkscreen);
}

void ConnectBox::erase (void)
{
	host.destroy();
	port.destroy();
	mnt.destroy();
	name.destroy();
	url.destroy();
	description.destroy();
	logintype.destroy();
	pass.destroy();
	bitrate.destroy();
	filtering.destroy();
	frequency.destroy();
	lowpasshz.destroy();
	highpasshz.destroy();
	channels.destroy();
	quality.destroy();
	bottom.destroy();
	label1.destroy();
	label2.destroy();
	icecastmenu.destroy();
	lamemenu.destroy();
}

void ConnectBox::activate (void)
{
	int quit=0, c;

	while (!quit)
	{
		bottom.setvalue ("<C>Use fields' shortcuts, set ic</48>e<!48>cast, set l</48>a<!48>me, or e</48></B>x<!B><!48>it");
		refresh();
		c=getch();
		switch (c) {
			case 'x':
				quit=1;
				break;
			case 'e':
				bottom.setvalue ("<C>Use icecast menu");
				icecast_menu();
				break;
			case 'a':
				bottom.setvalue ("<C>Use lame menu");
				lame_menu();
				break;
			default:
				quit=tabentry(c);
				break;
		}
	}
}

int ConnectBox::tabentry (int k)
{
	int retval = 0;
	int loop=0;

	while (!loop) {
		loop=1;

		bottom.setvalue("<C>Use TAB/Enter");


		switch (k) {
			case 'h': //host
				host.activate();
				if (host.lastkey() != 9) break;
			case 'o': //port
				port.activate();
				if (port.lastkey() != 9) break;
			case 'm': //mnt
				mnt.activate();
				if (mnt.lastkey() != 9) break;
			case 'n': //name
				name.activate();
				if (name.lastkey() != 9) break;
			case 'u': //url
				url.activate();
				if (url.lastkey() != 9) break;
			case 'd': //description
				description.activate();
				if (description.lastkey() != 9) break;
			case 'y': //logintype
				logintype.activate();
				if (logintype.lastkey() != 9) break;
			case 'p': //pass
				pass.activate();
				if (pass.lastkey() != 9) break;
			case 'b': //bitrate
				bitrate.activate();
				if (bitrate.lastkey() != 9) break;
			case 't': //frequency filtering
				filtering.activate();
				if (filtering.lastkey() != 9) break;
			case 'f': //frequency
				frequency.activate();
				if (frequency.lastkey() != 9) break;
			case 'l': //lowpass hz
				lowpasshz.activate();
				if (lowpasshz.lastkey() != 9) break;
			case 'i': //highpass hz
				highpasshz.activate();
				if (highpasshz.lastkey() != 9) break;
			case 'c': //channels
				channels.activate();
				if (channels.lastkey() != 9) break;
			case 'q': // quality
				quality.activate();
				if (quality.lastkey() != 9) break;
			case NULL:
				k='h'; // start from first case
				loop = 0;
				break;
			default:
				warning ("k = %d", k);
				retval = 0;
				break;
		}
	}
	return retval;
}

void ConnectBox::icecast_menu (void)
{
	int c;
	
	icecastmenu.reg();
	refresh();
	c=getch();
	switch (c)
	{
		case 'c':
			icecast_set();
			mixer->icecastout=true;
			mixer->ice.apply_profile();
			mixer->ice.start();
			break;
	}
	icecastmenu.unreg();
}

void ConnectBox::lame_menu (void)
{
	int c;

	lamemenu.reg();
	refresh();
	c=getch();
	switch (c)
	{
		case 'a': 
			lame_set();
			mixer->lame.apply_profile();
			break;
	}
	lamemenu.unreg();
}

void ConnectBox::showcurrval (void)
{
	char temp[32];

	// icecast settings
	host.setvalue (mixer->ice.ip);
	snprintf (temp, 32, "%d", mixer->ice.port);
	port.setvalue (temp);
	mnt.setvalue (mixer->ice.mount);
	name.setvalue (mixer->ice.name);
	url.setvalue (mixer->ice.url);
	description.setvalue (mixer->ice.desc);
	logintype.setitem (mixer->ice.login);
	pass.setvalue (mixer->ice.pass);
	
	//lame settings
	switch (mixer->lame.bps)
	{
		case 8: bitrate.setitem (0); break;
		case 16: bitrate.setitem (1); break;
		case 24: bitrate.setitem (2); break;
		case 32: bitrate.setitem (3); break;
		case 56: bitrate.setitem (4); break;
		case 64: bitrate.setitem (5); break;
		case 96: bitrate.setitem (6); break;
		case 128: bitrate.setitem (7); break;
	}

	//filtering.setitem ();
	switch (mixer->lame.freq)
	{
		//case auto: frequency.setitem (0); break;
		case 11000: frequency.setitem (1); break;
		case 16000: frequency.setitem (2); break;
		case 22050: frequency.setitem (3); break;
		case 44100: frequency.setitem (4); break;
	}

	snprintf (temp,32,"%d",mixer->lame.lowpass);
	lowpasshz.setvalue (temp);
	snprintf (temp,32,"%d",mixer->lame.highpass);
	highpasshz.setvalue (temp);
	channels.setitem (mixer->lame.mode);
	quality.setitem (mixer->lame.quality - 1);
}

void ConnectBox::lame_set (void)
{
	switch (bitrate.getcurritem())
	{
		case 0: mixer->lame.bps = 8; break;
		case 1: mixer->lame.bps = 16; break;
		case 2: mixer->lame.bps = 24; break;
		case 3: mixer->lame.bps = 32; break;
		case 4: mixer->lame.bps = 56; break;
		case 5: mixer->lame.bps = 64; break;
		case 6: mixer->lame.bps = 96; break;
		case 7: mixer->lame.bps = 128; break;
	}

	switch (frequency.getcurritem())
	{
	//	case 0: mixer->lame.freq = 0; break;
		case 1: mixer->lame.freq = 11000; break;
		case 2: mixer->lame.freq = 16000; break;
		case 3: mixer->lame.freq = 22050; break;
		case 4: mixer->lame.freq = 44100; break;
	}
	mixer->lame.lowpass = atoi (lowpasshz.getvalue());
	mixer->lame.highpass = atoi (highpasshz.getvalue());
	mixer->lame.mode = channels.getcurritem();
	mixer->lame.quality = quality.getcurritem() + 1;
}

void ConnectBox::icecast_set (void)
{
	strncpy (mixer->ice.ip, host.getvalue(), MAX_VALUE_SIZE);
	mixer->ice.port = atoi (port.getvalue());
	strncpy (mixer->ice.mount, mnt.getvalue(), MAX_VALUE_SIZE);
	strncpy (mixer->ice.name, name.getvalue(), MAX_VALUE_SIZE);
	strncpy (mixer->ice.url, url.getvalue(), MAX_VALUE_SIZE);
	strncpy (mixer->ice.desc, description.getvalue(), MAX_VALUE_SIZE);
	mixer->ice.login = logintype.getcurritem();
	strncpy (mixer->ice.pass, pass.getvalue(), MAX_VALUE_SIZE);
}

	
ConnectBox::~ConnectBox ()
{
	func ("ConnectBox::~ConnectBox"); 

	bottom.destroy();
	label1.destroy();
	label2.destroy();
	icecastmenu.destroy();
	lamemenu.destroy();

	if (cdkscreen) {
		destroyCDKScreen(cdkscreen);
		cdkscreen=NULL;
	}
}

==> MuSE-0.8.tar.gz: MuSE-0.8/ncursesgui/connectbox.cpp <==
/* A NCURSES/CDK TUI (Text User Interface) for MuSE
 * Copyright (C) 2002 Luca 'rubik' Profico <rubik@olografix.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: connectbox.cpp,v 1.14 2003/02/22 21:45:03 rubik Exp $
 *
 */

#include "connectbox.h"
#include "muse_console.h"

ConnectBox::ConnectBox (Stream_mixer *m)
{

	mixer = m ;

	func ("ConnectBox::ConnectBox");

	ybase = (LINES-CONNBOX_HEIGHT)/2;
	xbase = (COLS-CONNBOX_WIDTH)/2;
	subwin = newwin (CONNBOX_HEIGHT, CONNBOX_WIDTH, ybase, xbase);

	warning ("ConnBox pars: %d, %d, %d, %d",xbase, ybase,CONNBOX_WIDTH, CONNBOX_HEIGHT);

	cdkscreen = initCDKScreen (subwin);
	box (subwin, ACS_VLINE, ACS_HLINE);
	wrefresh (subwin);


	/* labels */
	bottom.setscreen (cdkscreen);

	encsetbox.setscreen (cdkscreen);
	//streamsetbox.setscreen (cdkscreen);



	/* load default profiles */

	/* nuova api
	mixer->lame.load_profile("last_active");
	mixer->ice.load_profile("last_active");
	*/
}

void ConnectBox::setparm (void)
{
	bottom.box=TRUE;
	bottom.setparm (xbase +3 , ybase + CONNBOX_HEIGHT,CONNBOX_WIDTH -6 ,1);
	bottom.llhook (ACS_BTEE);
	bottom.lrhook (ACS_BTEE);
	bottom.setvalue ("<C>Connbox");

	encsetbox.setparm(xbase, ybase);
	//streamsetbox.setparm();
	//showcurrval();
}

void ConnectBox::draw (void)
{

	bottom.draw();

	refresh();
}

void ConnectBox::refresh (void)
{
	refreshCDKScreen (cdkscreen);
}

void ConnectBox::erase (void)
{
	bottom.destroy();
	//encsetbox.cleanup();
}

void ConnectBox::activate (void)
{
	int quit=0, c;

	while (!quit)
	{
		//bottom.setvalue ("<C>Use fields' shortcuts, set ic</48>e<!48>cast, set l</48>a<!48>me, or e</48></B>x<!B><!48>it");
		bottom.setvalue ("<C>Set La</48>m<!48>e/</48>O<!48>GG, edit </48>s<!48>ervers or e</48>x<!48>it");
		refresh();
		c=getch();
		switch (c) {
			case 'x':
				quit=1;
				break;
			case 'm':
			case 'M':
				bottom.setvalue ("<C></48>S<!48>ave/</48>L<!48>oad profiles, </48>a<!48>pply");
				encsetbox.draw();
				c=getch();
				encsetbox.unreg();
				//icecast_menu();
				break;
			case 'o':
			case 'O':
				bottom.setvalue ("<C></48>S<!48>ave/</48>L<!48>oad profiles, </48>a<!48>pply");
				encsetbox.draw();
				c=getch();
				//lame_menu();
				break;
			default:
				//quit=tabentry(c);
				break;
		}
	}
}

	
ConnectBox::~ConnectBox ()
{
	warning ("ConnectBox::~ConnectBox objcnt = %d [BEGIN]", cdkscreen->objectCount); 

	//bottom.destroy();

	encsetbox.cleanup();

	warning ("ConnectBox::~ConnectBox objcnt = %d ", cdkscreen->objectCount); 
	if (cdkscreen) {
		destroyCDKScreen(cdkscreen);
		cdkscreen=NULL;
	}
	warning ("ConnectBox::~ConnectBox objcnt [END]"); 
}
